/*
 * Copyright (c) 2019-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.scanner.entity;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import static org.hedgecode.chess.scanner.format.PGNConstants.*;

/**
 * PGNTournament
 *
 * @author Dmitry Samoshin aka gotty
 */
public class PGNTournament implements PGNEntity {

    private String tournamentId;
    private String tournamentName;

    private List<PGNGame> tournamentGames = new ArrayList<>();

    public PGNTournament(String tournamentId) {
        this.tournamentId = tournamentId;
    }

    public PGNTournament(String tournamentId, String tournamentName) {
        this.tournamentId = tournamentId;
        this.tournamentName = tournamentName;
    }

    public void addGame(PGNGame game) {
        tournamentGames.add(game);
    }

    public void addGames(Collection<PGNGame> games) {
        tournamentGames.addAll(games);
    }

    public void clearGames() {
        tournamentGames.clear();
    }

    public List<PGNGame> games() {
       return tournamentGames;
    }

    @Override
    public String id() {
        return tournamentId;
    }

    public String name() {
        return tournamentName;
    }

    public void setName(String name) {
        tournamentName = name;
    }

    @Override
    public String pgn() {
        StringBuilder sb = new StringBuilder();
        for (PGNGame game : tournamentGames) {
            sb.append(
                    game.pgn()
            ).append(
                    PGN_CRLF
            );
        }
        return sb.toString();
    }

}
