/*
 * Copyright (c) 2019-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.scanner.format;

import static org.hedgecode.chess.scanner.format.PGNConstants.*;

/**
 * ReducePGNFormat
 *
 * @author Dmitry Samoshin aka gotty
 */
public class ReducePGNFormat extends AbstractPGNFormat {

    @Override
    public String format() {
        StringBuilder sb = new StringBuilder();
        for (PGNTag tag : PGNTag.tags()) {
            String tagValue = getTag(tag);
            if (tag.isRequired() || tagValue != null) {
                sb.append(
                        String.format(
                                PGNTag.TAG_FORMAT,
                                tag.getName(),
                                tagValue != null ? formatTagValue(tagValue) : tag.defaultValue()
                        )
                ).append(PGN_CRLF);
            }
        }
        sb.append(PGN_CRLF).append(
                formatMoves()
        ).append(PGN_CRLF);
        return sb.toString();
    }

}
