/*
 * Copyright (c) 2019-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.scanner.format.lichess;

import org.hedgecode.chess.scanner.spi.ServiceRegistry;

/**
 * Format
 *
 * @author Dmitry Samoshin aka gotty
 */
public final class Format {

    private static Format _instance;

    private final FormatBuilder formatBuilder;

    private Format() {
        formatBuilder = ServiceRegistry.singleProvider(
                FormatBuilder.class
        );
    }

    public static GameFormat formatGame(String game) {
        return getFormat().builder().buildGame(game);
    }

    private FormatBuilder builder() {
        return formatBuilder;
    }

    private static Format getFormat() {
        if (_instance == null) {
            _instance = new Format();
        }
        return _instance;
    }

}
