/*
 * Copyright (c) 2019-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.scanner.json.chessbomb;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;

import org.hedgecode.chess.scanner.format.chessbomb.ArenaFormat;
import org.hedgecode.chess.scanner.format.chessbomb.FormatBuilder;
import org.hedgecode.chess.scanner.format.chessbomb.GameFormat;
import org.hedgecode.chess.scanner.format.chessbomb.TournamentFormat;

/**
 * JSONFormatBuilder
 *
 * @author Dmitry Samoshin aka gotty
 */
public class JSONFormatBuilder implements FormatBuilder {

    private static final Gson GSON = new GsonBuilder().create();

    @Override
    public GameFormat buildGame(String jsonGame) {
        return GSON.fromJson(
                jsonGame,
                JSONGameFormat.class
            );
    }

    @Override
    public TournamentFormat buildTournament(String jsonTournament) {
        return GSON.fromJson(
                jsonTournament,
                JSONTournamentFormat.class
        );
    }

    @Override
    public ArenaFormat buildArena(String jsonArena) {
        return GSON.fromJson(
                jsonArena,
                JSONArenaFormat.class
        );
    }

}
