/*
 * Copyright (c) 2019-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.scanner.json.chessbomb;

import com.google.gson.annotations.SerializedName;

import org.hedgecode.chess.scanner.format.PGNFormat;
import org.hedgecode.chess.scanner.format.PGNTag;
import org.hedgecode.chess.scanner.format.chessbomb.GameData;
import org.hedgecode.chess.scanner.format.chessbomb.GameFormat;
import org.hedgecode.chess.scanner.format.TypeMovesFormat;
import org.hedgecode.chess.scanner.spi.ServiceRegistry;

/**
 * JSONGameFormat
 *
 * @author Dmitry Samoshin aka gotty
 */
public class JSONGameFormat extends AbstractBaseFormat implements GameFormat {

    @SerializedName("gameData")
    private JSONGameData gameData;

    JSONGameFormat() {
    }

    @Override
    public String id() {
        return Integer.toString(
                gameData.game().id()
        );
    }

    @Override
    public GameData gameData() {
        return gameData;
    }

    @Override
    public String pgn() {
        PGNFormat pgnFormat = ServiceRegistry.singleProvider(
                PGNFormat.class
        );
        pgnFormat.addTag(PGNTag.EVENT, gameData.room().name());
        pgnFormat.addTag(PGNTag.DATE, pgnFormat.formatDate(gameData.game().startAt()));
        pgnFormat.addTag(PGNTag.ROUND, gameData.game().roundSlug());
        pgnFormat.addTag(PGNTag.WHITE, gameData.game().white().name());
        pgnFormat.addTag(PGNTag.BLACK, gameData.game().black().name());
        pgnFormat.addTag(PGNTag.WHITE_TITLE, gameData.game().white().title());
        pgnFormat.addTag(PGNTag.BLACK_TITLE, gameData.game().black().title());
        pgnFormat.addTag(PGNTag.WHITE_ELO, Integer.toString(gameData.game().whiteElo()));
        pgnFormat.addTag(PGNTag.BLACK_ELO, Integer.toString(gameData.game().blackElo()));
        pgnFormat.addTag(PGNTag.EVENT_DATE, pgnFormat.formatDate(gameData.room().startAt()));
        pgnFormat.addTag(PGNTag.TIME, pgnFormat.formatTime(gameData.game().startAt()));
        pgnFormat.addTag(PGNTag.RESULT, gameData.game().result());
        if (gameData.moves().length > 0) {
            pgnFormat.addTag(PGNTag.PLY_COUNT, Integer.toString(gameData.moves().length));
        }
        pgnFormat.addMoves(
                TypeMovesFormat.WRAP.format(gameData.moves())
        );
        return pgnFormat.format();
    }

}
