/*
 * Copyright (c) 2019-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.scanner.proxy.type;

import java.net.Authenticator;

import org.hedgecode.chess.scanner.proxy.ProxySetter;

/**
 * SOCKS proxy server setter.
 *
 * @author Dmitry Samoshin aka gotty
 */
public class SOCKSSetter implements ProxySetter {

    @Override
    public void setProxyHost(String proxyHost) {
        System.setProperty("socksProxyHost", proxyHost);
    }

    @Override
    public void setProxyPort(String proxyPort) {
        System.setProperty("socksProxyPort", proxyPort);
    }

    @Override
    public void setProxyAuth(String user, String password) {
        System.setProperty("java.net.socks.username", user);
        System.setProperty("java.net.socks.password", password);
        Authenticator.setDefault(
                new ProxyAuthenticator(user, password)
        );
    }

}
