/*
 * Copyright (c) 2019-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.scanner.regex;

/**
 * RegexParams
 *
 * @author Dmitry Samoshin aka gotty
 */
public final class RegexParams {

    public static final String TOURNAMENT_ID = "[tournamentId]";
    public static final String PAGE_ID = "[pageId]";
    public static final String GAME_ID = "[gameId]";
    public static final String QUERY = "[query]";

    private String tournamentId;
    private String pageId;
    private String gameId;
    private String query;
    private boolean isUrlEncode;

    public RegexParams(String tournamentId, String pageId) {
        this.tournamentId = tournamentId;
        this.pageId = pageId;
    }

    public RegexParams(String gameId) {
        this.gameId = gameId;
    }

    public RegexParams(String gameId, String tournamentId, boolean withTournament) {
        this.gameId = gameId;
        if (withTournament) {
            this.tournamentId = tournamentId;
        }
    }

    public RegexParams(String query, boolean isUrlEncode) {
        this.query = query;
        this.isUrlEncode = isUrlEncode;
    }

    public String getTournamentId() {
        return tournamentId;
    }

    public String getPageId() {
        return pageId;
    }

    public String getGameId() {
        return gameId;
    }

    public String getQuery() {
        return query;
    }

    public boolean isUrlEncode() {
        return isUrlEncode;
    }

}
