/*
 * Copyright (c) 2019-2020. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.scanner.regex;

import org.hedgecode.chess.scanner.regex.type.RegexBlockFinder;
import org.hedgecode.chess.scanner.regex.type.RegexFinder;
import org.hedgecode.chess.scanner.regex.type.RegexSplitter;

/**
 * RegexType
 *
 * @author Dmitry Samoshin aka gotty
 */
public enum RegexType {

    FIND,
    SPLIT,
    BLOCK;

    public static RegexMatcher matcher(RegexType type, String match) {
        return Factory.create(
                type,
                match
        );
    }

    public static RegexMatcher matcher(String startMatch, String endMatch) {
        return Factory.create(
                startMatch,
                endMatch
        );
    }

    static class Factory {

        static RegexMatcher create(RegexType type, String match) {
            switch (type) {
                case FIND:
                    return new RegexFinder(match);
                case SPLIT:
                    return new RegexSplitter(match);
                case BLOCK:
                    return new RegexBlockFinder(match, match);
            }
            return null;
        }

        static RegexMatcher create(String startMatch, String endMatch) {
            return new RegexBlockFinder(startMatch, endMatch);
        }

        private Factory() {
        }

    }

}
